==> fujicoin-0.19.0.2.tar.gz: fujicoin-0.19.0.2/src/qt/locale/fujicoin_te.ts <==
<TS language="te" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>చిరునామా లేదా లేబుల్ సవరించడానికి రైట్-క్లిక్ చేయండి</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>క్రొత్త చిరునామా సృష్టించండి</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;క్రొత్త</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>ప్రస్తుతం ఎంచుకున్న చిరునామాను సిస్టం క్లిప్ బోర్డుకు కాపీ చేయండి</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;కాపి</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;కోల్పోవు</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>ప్రస్తుతం ఎంచుకున్న చిరునామా ను జాబితా నుండి తీసివేయండి</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>చిరునామా లేదా ఏదైనా పేరును వెతకండి</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ప్రస్తుతం ఉన్న సమాచారాన్ని ఫైల్ లోనికి ఎగుమతి చేసుకోండి</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>ఎగుమతి చేయండి</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>తొలగించండి</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>కోయిన్స్ పంపుటకు చిరునామా ను ఎంచుకోండి</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>నాణెం అందుకోవటానికి చిరునామాను ఎంచుకోండి</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>ఎంచుకోండి</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>పంపించే చిరునామాలు</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>అందుకునే చిరునామాలు</translation>
    </message>
    <message>
        <source>These are your Fujicoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>ఇవి మీరు పంపే చెల్లింపుల బిట్‌కాయిన్ చిరునామాలు. నాణేలు పంపే ముందు ప్రతిసారి అందుకునే చిరునామా మరియు చెల్లింపు మొత్తం సరిచూసుకోండి.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>చిరునామాను కాపీ చెయ్యండి</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>కాపీ &amp; ఉల్లాకు</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>సవరించు</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>చిరునామా జాబితాను ఎగుమతి చేయండి</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>కోమా వల్ల విభజించిన ఫైల్ (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ఎగుమతి విఫలమయ్యింది</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>చిరునామా పట్టికను %1 లోనికి ప్రోదుపరుచుటలో లోపము. మరుల ప్రయత్నించి చుడండి.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>ఉల్లాకు</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>చిరునామా</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>( ఉల్లాకు లేదు )</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>సంకేతపదము డైలాగ్</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>సంకేతపదము చేర్చండి</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>క్రొత్త సంకేతపదము</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>క్రొత్త సంకేతపదము మరలా ఇవ్వండి</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>వాలెట్ అన్లాక్</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR FUJICOINS&lt;/b&gt;!</source>
        <translation>హెచ్చరిక: మీ జోలెని సంకేతపరిచి మీ సంకేతపదము కోల్పోతే, &lt;b&gt;మీ బిట్‌కాయిన్లు అన్నీ కోల్పోతారు&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>మీరు ఖచ్చితంగా మీ జోలెని సంకేతపరచాలని కోరుకుంటున్నారా?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>జోలె సంకేతపరబడింది</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>జోలె సంకేతపరచడం విఫలమయ్యింది</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>FujicoinGUI</name>
    <message>
        <source>E&amp;xit</source>
        <translation>నిష్క్రమించు</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>పంపు</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>లోపం</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>హెచ్చరిక</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>వర్తమానము</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>తాజాగా ఉంది</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>తోటివాళ్లతో అనుసంధానం కుదురుస్తుంది</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>నాణెం ఎంపిక</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>పరిమాణం</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>తేదీ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>( ఉల్లాకు లేదు )</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Fujicoin</source>
        <translation>బిట్కోయిన్</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>లోపం</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation>లోపం</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>unknown</source>
        <translation>తెలియదు</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>చిరునామా</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ఉల్లాకు</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>సందేశం</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>వాలెట్</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>తేదీ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ఉల్లాకు</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>సందేశం</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>( ఉల్లాకు లేదు )</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>పరిమాణం</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>( ఉల్లాకు లేదు )</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Status</source>
        <translation>స్థితి</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>తేదీ</translation>
    </message>
    <message>
        <source>From</source>
        <translation>నుండి</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>తెలియదు</translation>
    </message>
    <message>
        <source>To</source>
        <translation>కు</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>సందేశం</translation>
    </message>
    <message>
        <source>Merchant</source>
        <translation>వర్తకుడు</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>తేదీ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ఉల్లాకు</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>( ఉల్లాకు లేదు )</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>కోమా వల్ల విభజించిన ఫైల్ (*.csv)</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>తేదీ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ఉల్లాకు</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>చిరునామా</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>గుర్తింపు</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ఎగుమతి విఫలమయ్యింది</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>ఎగుమతి చేయండి</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ప్రస్తుతం ఉన్న సమాచారాన్ని ఫైల్ లోనికి ఎగుమతి చేసుకోండి</translation>
    </message>
    </context>
<context>
    <name>fujicoin-core</name>
    </context>
</TS>

==> fujicoin-0.21.0.1.tar.gz: fujicoin-0.21.0.1/src/qt/locale/fujicoin_te.ts <==
<TS language="te" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>చిరునామా లేదా లేబుల్ సవరించడానికి రైట్-క్లిక్ చేయండి</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>క్రొత్త చిరునామా సృష్టించండి</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;క్రొత్త</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>ప్రస్తుతం ఎంచుకున్న చిరునామాను సిస్టం క్లిప్ బోర్డుకు కాపీ చేయండి</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;కాపి</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;కోల్పోవు</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>ప్రస్తుతం ఎంచుకున్న చిరునామా ను జాబితా నుండి తీసివేయండి</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>చిరునామా లేదా ఏదైనా పేరును వెతకండి</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ప్రస్తుతం ఉన్న సమాచారాన్ని ఫైల్ లోనికి ఎగుమతి చేసుకోండి</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>ఎగుమతి చేయండి</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>తొలగించండి</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>కోయిన్స్ పంపుటకు చిరునామా ను ఎంచుకోండి</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>నాణెం అందుకోవటానికి చిరునామాను ఎంచుకోండి</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>ఎంచుకోండి</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>పంపించే చిరునామాలు</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>అందుకునే చిరునామాలు</translation>
    </message>
    <message>
        <source>These are your Fujicoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>ఇవి మీరు పంపే చెల్లింపుల బిట్‌కాయిన్ చిరునామాలు. నాణేలు పంపే ముందు ప్రతిసారి అందుకునే చిరునామా మరియు చెల్లింపు మొత్తం సరిచూసుకోండి.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>చిరునామాను కాపీ చెయ్యండి</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>కాపీ &amp; ఉల్లాకు</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>సవరించు</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>చిరునామా జాబితాను ఎగుమతి చేయండి</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>కోమా వల్ల విభజించిన ఫైల్ (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ఎగుమతి విఫలమయ్యింది</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>చిరునామా పట్టికను %1 లోనికి ప్రోదుపరుచుటలో లోపము. మరుల ప్రయత్నించి చుడండి.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>ఉల్లాకు</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>చిరునామా</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>( ఉల్లాకు లేదు )</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>సంకేతపదము డైలాగ్</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>సంకేతపదము చేర్చండి</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>క్రొత్త సంకేతపదము</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>క్రొత్త సంకేతపదము మరలా ఇవ్వండి</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>సంకేతపదమును చూపించు</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>వాలెట్‌ను గుప్తీకరించండి</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>ఈ ఆపరేషన్‌కు వాలెట్‌ను అన్‌లాక్ చేయడానికి మీ వాలెట్ పాస్‌ఫ్రేజ్ అవసరం.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>వాలెట్ అన్లాక్</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>ఈ ఆపరేషన్‌కు వాలెట్‌ను డీక్రిప్ట్ చేయడానికి మీ వాలెట్ పాస్‌ఫ్రేజ్ అవసరం.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>డీక్రిప్ట్ వాలెట్</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>పాస్‌ఫ్రేజ్‌ని మార్చండి</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>వాలెట్ గుప్తీకరణను నిర్ధారించండి</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR FUJICOINS&lt;/b&gt;!</source>
        <translation>హెచ్చరిక: మీ జోలెని సంకేతపరిచి మీ సంకేతపదము కోల్పోతే, &lt;b&gt;మీ బిట్‌కాయిన్లు అన్నీ కోల్పోతారు&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>మీరు ఖచ్చితంగా మీ జోలెని సంకేతపరచాలని కోరుకుంటున్నారా?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>జోలె సంకేతపరబడింది</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>వాలెట్ కోసం క్రొత్త పాస్‌ఫ్రేజ్‌ని నమోదు చేయండి.&lt;br/&gt; దయచేసి &lt;b&gt;పది లేదా అంతకంటే ఎక్కువ యాదృచ్ఛిక అక్షరాల&lt;/b&gt; పాస్‌ఫ్రేజ్‌ని లేదా &lt;b&gt;ఎనిమిది లేదా అంతకంటే ఎక్కువ పదాలను ఉపయోగించండి.&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>Enter the old passphrase and new passphrase for the wallet.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your fujicoins from being stolen by malware infecting your computer.</source>
        <translation>మీ వాలెట్‌ను గుప్తీకరించడం వల్ల మీ కంప్యూటర్‌కు హాని కలిగించే మాల్వేర్ దొంగిలించకుండా మీ బిట్‌కాయిన్‌లను పూర్తిగా రక్షించలేమని గుర్తుంచుకోండి.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>ఎన్క్రిప్ట్ చేయవలసిన వాలెట్</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>మీ వాలెట్ గుప్తీకరించబోతోంది.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>జోలె సంకేతపరచడం విఫలమయ్యింది</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>FujicoinGUI</name>
    <message>
        <source>E&amp;xit</source>
        <translation>నిష్క్రమించు</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>పంపు</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>లోపం</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>హెచ్చరిక</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>వర్తమానము</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>తాజాగా ఉంది</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>తోటివాళ్లతో అనుసంధానం కుదురుస్తుంది</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>నాణెం ఎంపిక</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>పరిమాణం</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>తేదీ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>( ఉల్లాకు లేదు )</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Fujicoin</source>
        <translation>బిట్కోయిన్</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>లోపం</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation>లోపం</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>unknown</source>
        <translation>తెలియదు</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>తేదీ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ఉల్లాకు</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>సందేశం</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>( ఉల్లాకు లేదు )</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>పరిమాణం</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>( ఉల్లాకు లేదు )</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Status</source>
        <translation>స్థితి</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>తేదీ</translation>
    </message>
    <message>
        <source>From</source>
        <translation>నుండి</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>తెలియదు</translation>
    </message>
    <message>
        <source>To</source>
        <translation>కు</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>సందేశం</translation>
    </message>
    <message>
        <source>Merchant</source>
        <translation>వర్తకుడు</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>తేదీ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ఉల్లాకు</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>( ఉల్లాకు లేదు )</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>కోమా వల్ల విభజించిన ఫైల్ (*.csv)</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>తేదీ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ఉల్లాకు</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>చిరునామా</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>గుర్తింపు</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ఎగుమతి విఫలమయ్యింది</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>ఎగుమతి చేయండి</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ప్రస్తుతం ఉన్న సమాచారాన్ని ఫైల్ లోనికి ఎగుమతి చేసుకోండి</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>లోపం</translation>
    </message>
    </context>
<context>
    <name>fujicoin-core</name>
    </context>
</TS>
